==> monet-1.0.18.jar: gen/displays/templates/CheckListWizardIndexEntry.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiAction from "alexandria-ui-elements/src/displays/components/Action";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import CheckListWizardIndexEntryNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import CheckListWizardIndexEntryRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class CheckListWizardIndexEntry extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new CheckListWizardIndexEntryNotifier(this);
		this.requester = new CheckListWizardIndexEntryRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="topDottedBordered checkListWizardIndexEntryStyle" layout="vertical" style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2044440008" layout="horizontal flexible">
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2044440008.a1685070970" layout="vertical" width="30.0%" height="100.0%">
						<UiAction context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2044440008.a1685070970.a2091095818" title="" target="self" mode="Link" size="Medium" format="bold">
						</UiAction>
					</UiBlock>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2044440008.a1591419440" layout="vertical" width="70.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2044440008.a1591419440.a_1283829296" mode="normal">
						</UiText>
					</UiBlock>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(CheckListWizardIndexEntry));
DisplayFactory.register("CheckListWizardIndexEntry", withStyles(styles, { withTheme: true })(withSnackbar(CheckListWizardIndexEntry)));

==> monet-1.0.54.jar: gen/displays/templates/CheckListWizardIndexEntry.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiAction from "alexandria-ui-elements/src/displays/components/Action";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import CheckListWizardIndexEntryNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import CheckListWizardIndexEntryRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class CheckListWizardIndexEntry extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new CheckListWizardIndexEntryNotifier(this);
		this.requester = new CheckListWizardIndexEntryRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="topDottedBordered checkListWizardIndexEntryStyle" layout="vertical" style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a232441302" layout="horizontal flexible">
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a232441302.a1448774202" layout="vertical" width="30.0%" height="100.0%">
						<UiAction context={this._context.bind(this)} owner={this._owner.bind(this)} id="a232441302.a1448774202.a_592930520" title="" target="self" mode="Link" size="Medium" format="bold">
						</UiAction>
					</UiBlock>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a232441302.a_1438813072" layout="vertical" width="70.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a232441302.a_1438813072.a642204782" mode="normal">
						</UiText>
					</UiBlock>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(CheckListWizardIndexEntry));
DisplayFactory.register("CheckListWizardIndexEntry", withStyles(styles, { withTheme: true })(withSnackbar(CheckListWizardIndexEntry)));
